Greyhorse core library
======================

Modular framework for building pythonic microservices


How to build
------------


- Install the project

    ``uv python pin 3.12.1``

    ``uv venv``

    ``uv sync``

    ``source .venv/bin/activate``



- Format code commands

    ``ruff check --unsafe-fixes --fix``

    ``ruff format``
